module Experian
  class DataDictionary
    def self.en_0717_column_name
      'Estimated Current Mortgage Amount Ranges'
    end

    def self.en_0717_value_description(_key)
      ''
    end

    def self.en_0717_description
      'Estimated Current Mortgage Amount model predicts the amount currently remaining on the primary mortgage. It projects the amount owed on the mortgage by using the original mortgage amount or refinance amount; even where known mortgage data is not available. When data is not available from deed records, ECMA is calculated based on a combination of real estate data including estimated current home value and other ConsumerView variables such as demographics, summarized credit and auto data, and census. A confidence level of Likely is applied when the known data is not available.'
    end

    def self.en_0717(key)
      confidence = {
        '1' => 'Extremely Likely',
        '2' => 'Highly Likely',
        '3' => 'Likely'
      }

      values = {
        'A' => '1,000 - 9,999',
        'B' => '10,000 - 24,999',
        'C' => '25,000 - 39,999',
        'D' => '40,000 - 59,999',
        'E' => '60,000 - 79,999',
        'F' => '80,000 - 99,999',
        'G' => '100,000 - 119,999',
        'H' => '120,000 - 139,999',
        'I' => '140,000 - 159,999',
        'J' => '160,000 - 199,999',
        'K' => '200,000 - 249,999',
        'L' => '250,000 - 249,999',
        'M' => '350,000 - 449,999',
        'N' => '450,000 - 749,999',
        'O' => '750,000 - 999,999',
        'P' => '1,000,000 - +',
        'U' => 'Unknown'
      }

      return 'Unknown' if key.size != 2 || confidence[key[0]].nil? || values[key[1]].nil?
      [values[key[1]], confidence[key[0]]].join(' - ')
    end
  end
end
